@@ -51,7 +51,16 @@ setMethod("dim", signature(x="float32"), function(x) c(nrow(x), ncol(x)))
 
 #' @rdname dims
 #' @export
-setMethod("length", signature(x="float32"), function(x) nrow(x)*ncol(x))
+setMethod("length", signature(x="float32"), 
+  function(x)
+  {
+    len = tryCatch(nrow(x) * ncol(x), warning=identity)
+    if (inherits(len, "warning"))
+      len = as.double(nrow(x)) * as.double(ncol(x))
+    
+    len
+  }
+)
 
 
 
